capture log close
log using cda14-gettingstarted, replace text
version 13.1
clear all
set linesize 80
matrix drop _all

//  program:    cda14-gettingstarted.do
//  task:       Getting started using Stata
//  project:    CDA
//  author:     Scott Long & Tom VanHeuvelen 2014-06-04

//  #1 Exploring Your Data

* load data, use spex gettingstarted1, clear if spost os installed
use gettingstarted1, clear

* save the data to your working directory
save gettingstarted1-jsl, replace // my initials added

* look at a list of Stata example datasets
sysuse dir

* look at the spreadsheet of your data
browse

* names, labels and summary statistics
describe
summarize
codebook, compact
codebook female phd
summarize female phd, detail

* listing observations
sort pubtot
list id pubtot female phdclass jobprst enrol in 1/5
list id pubtot female phdclass jobprst enrol if pubtot==0
list id pubtot female phdclass jobprst enrol in -5/L

* variable distributions
tabulate female, miss
tab phdclass female, miss
tab1 phdclass female, miss
histogram phdclass, freq
twoway scatter phd pubtot
graph matrix female phd pubtot, half
graph export cda14-gettingstarted-fig1.png, width(1200) replace

//  #2 Data Management

* generating new variables
gen totcit = cit1 + cit3 + cit6 + cit9
note totcit: sum cit1 cit3 cit6 cit9 | jsl cda14-gettingstarted.do 2014-06-04.
label var totcit "Total # of citations"
list cit1 cit3 cit6 cit9 totcit in 1/5

gen phdcat = phd
label var phdcat "PhD prestige categories"
recode phdcat (.=.) (1/1.99=1) (2/2.99=2) (3/3.99=3) (4/5=4)
label define phdcat 1 "1_Adeq" 2 "2_Good" 3 "3_Strong" 4 "4_Dist"
label value phdcat phdcat
tab phdcat, miss

* method 1
gen workres = work
label var workres "Work as a researcher?"
labe var workres "Research work?"
recode workres (.=.) (1=0) (2=1) (3=0) (4=1) (5=0)
* or use: replace workres = 1 if work==2 | work==4
*         replace workres = 0 if work==1 | work==3 | work==5
label define workres 0 "0_NotRes" 1 "1_Resrchr"
label value  workres workres
tab work workres

* method 2
gen workres2 = (work==2 | work==4) if (work<.)
label var workres2  "Work as a researcher?"
label value workres2 workres
tab work workres2

//  #3 Beyond the Basics

* storing estimates & creating tables
logit workfac fellow mcit3 phd, nolog
estimates store full

logit workfac fellow mcit3, nolog
estimates store nophd

estimates table full nophd, t

* using Stata as a calculator
display 2+2
di 2^5
di exp(2.915)
di ln(exp(2.915))

* data label and note
label data "scott's revisions to getting started data | 2014-05-30"
note: gettingstarted1-jslV2.dta | data, added vars totcit, phdcat, ///
workres, and workres2 | cda14-gettingstarted.do scott long 2014-06-04.
save gettingstarted1-jslV2, replace

* check data
use gettingstarted1-jslV2, clear
notes _dta
note totcit

//  #5 locals

local tag "cda14-gettingstarted.do scott long 2014-06-04"
note workres: created from work | `tag'.
note workres

local rhs "workfac enrol phd"
regress pubtot `rhs'

log close
exit
