capture log close
log using wfauto-08estout, replace text
version 13.1
clear all
set linesize 80
macro drop _all
set scheme s2manual

//  Guide to Automating Your Work in Stata
//  Scott Long & Bianca Manago
//  estout

local pgm wfauto-08estout
local dte 2015-05-13
local who scott long
local tag  "`pgm' `who' `dte'"

//  load data

use wf-lfp, clear
notes

//  #1 setup for models

local demog     k5 k618 age
local college   i.wc i.hc
local earn      lwg inc

local model1 `demog'
local model2 `model1' `college'
local model3 `model2' `earn'

//  #2 estimate models

local mytable ""
forvalues i = 1(1)3 {
  quietly logit lfp `model`i''
  eststo results`i'
  local mytable "`mytable' results`i'"
}

//  #4 The esttab default table

esttab `mytable'

//  #3 Customizing the table with labels

esttab `mytable' , ///
  title("Table 1: Models of female labor force participation") /// table title
  mtitle("Demographics" "(1)+College" "(2)+Earnings") /// label models
  coef(                                    /// label variables in model
    k5       "Number of kids under 6"      ///
    k618     "Number of kids 6-18"         ///
    age      "Age"                         ///
    1.wc     "Wife attended college"       ///
    1.hc     "Husband attended college"    ///
    lwg      "ln(Wife's estimated wages)"  ///
    inc      "Family income"               ///
    _cons    "Constant"                    ///
    )                                      ///
  varwidth(30)                             ///
  nobase                                   ///

//  #4 Adding sub-table text

esttab `mytable' , ///
  title("Table 1: Models of female labor force participation") /// title
  mtitle("Demographics" "(1)+College" "(2)+Earnings") /// label models
  coef(                                    /// label variables in model
    k5       "Number of kids under 6"      ///
    k618     "Number of kids 6-18"         ///
    age      "Age"                         ///
    1.wc     "Wife attended college"       ///
    1.hc     "Husband attended college"    ///
    lwg      "ln(Wife's estimated wages)"  ///
    inc      "Family income"               ///
    _cons    "Constant"                    ///
    )                                      ///
  varwidth(30)                             ///
  nolegend /// suppress significance legend, I'm adding it myself
  addnote("* p<0.05 ** p<0.01 *** p<0.001" ///
          "" /// blank line
          "`tag'") /// add notes below table
  scalar("ll Log lik.") bic pr2 /// show model fit statistics

//  #5 Enhance (and export)

esttab `mytable' using `pgm'.rtf , replace ///
  title("Table 1: Models of female labor force participation") /// title
  mtitle("Demographics" "(1)+College" "(2)+Earnings") /// label models
  coef(                                    /// label variables in model
    k5       "Number of kids under 6"      ///
    k618     "Number of kids 6-18"         ///
    age      "Age"                         ///
    1.wc     "Wife attended college"       ///
    1.hc     "Husband attended college"    ///
    lwg      "ln(Wife's estimated wages)"  ///
    inc      "Family income"               ///
    _cons    "Constant"                    ///
    )                                      ///
  varwidth(30)                             ///
  nolegend /// suppress significance legend, I'm adding it myself
  addnote("* p<0.05 ** p<0.01 *** p<0.001" ///
          "" /// blank line
          "`tag'") /// add notes below table
  scalar("ll Log lik.") bic pr2 /// show model fit statistics
  eform /// show odds ratios , not coefficients
  constant /// do not suppress constant
  stardrop(_cons, relax)                  ///
  b(3) /// decimal points for coefficients
  t(2) /// decimal points for test statistic
  indicate("College controls = 1.wc 1.hc" "Earnings controls = lwg inc") ///
  nobase

* esttab `mytable' using `pgm'.tex , replace ///  export to tex tile
* esttab `mytable' using `pgm'.csv , replace ///  export to excel file

log close
exit
