capture log close
log using wflec-clean-examples, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: clean - methods of cleaning

global pgm wflec-clean-examples
global dte 2017-06-19
global who Scott Long
global tag "$pgm.do $who $dte"

//  values review ============================================================

//  #1 values: wf-acjob data

use wf-acjob, clear

* check range of values

codebook, compact

* check specific values

tab1 art, missing
tab1 fem fel, missing

* histograms with a loop

foreach varname in art cit phd job ment {
    stem `varname' // graph made with text
}

foreach varname in art cit phd job ment {
    local varlbl : variable label `varname'
    label var `varname' "`varname': `varlbl'" // add name to var lab
    dotplot `varname' // graph file
    graph export $pgm-wf-acjob-`varname'.png, replace
}

//  #2 value: wf-gsswarm data

use wf-gsswarm, clear

tab v4, miss
tab v4, miss nolab

//  #3 substantive: wf-acpub

use wf-acpub, replace // simulated data

* fit model with supposedly correct data

nbreg pub enrol phd female, nolog irr

* check enrol

tabulate enrol, miss
pwcorr pub enrol

* fit model with corrected variable for enrolled time

nbreg pub enrol_fixed phd female, nolog irr

* compare distributions

label var enrol_fixed "enroll_fixed: enrolled time"
label var enrol "enrol: elapsed time"
dotplot enrol_fixed enrol, ///
    ytitle("Years",size(medium)) xlabel(,labsize(medium))
graph export $pgm-wf-acpub-timetophd.emf, replace

//  substantive review =======================================================

//  #4 substantive: wf-acjob

use wf-acjob, clear

* phd spike

sum phd
dotplot phd
graph export $pgm-wf-acjob-phd.emf, replace
tab phd if phd >4 & phd<4.5

* link between phd and job

codebook phd job, compact

label var phd "phd: PhD prestige"
label var job "job: Prestige of first job"
dotplot phd job, xlab(,labsize(medium))
graph export $pgm-wf-acpub-phd+job.emf, replace

scatter job phd, msym(circle_hollow) jitter(8) ///
    ylab(, grid) xlab(, grid) aspectratio(1)
graph export $pgm-wf-acpub-phdXjob.emf, replace

//  missing review ===========================================================

use wf-missing, clear

//  #1 review missing values

* list only missing values

foreach varname in phd art cit {
    tab1 `varname' if missing(`varname'), missing
}

* look at the distribution of articles

tabulate art, missing
tabulate art
summarize art

//  #2 missing values that are not missing

* recode large numbers to 5
generate art_tr5 = art
replace art_tr5 = 5 if art>5
label var art_tr5 "trunc at 5 # of articles published"
summarize art art_tr5
set linesize 100
tabulate art art_tr5, missing

* selecting valid cases with comparisons
generate art_tr5V2 = art
replace art_tr5V2 = 5 if art>5 & art<.
label var art_tr5V2 "trunc at 5 # of articles published"
note art_tr5V2: created using art<.
tabulate art_tr5V2, missing

* selecting valid cases with the missing function
generate art_tr5V3 = art
replace art_tr5V3 = 5 if art>5 & !missing(art)
label var art_tr5V3 "trunc at 5 # of articles published"
note art_tr5V3: created using !missing(art)
tabulate art_tr5V3, missing

//  #4 create missing value indicator

generate art_ismiss = missing(art)
label var art_ismiss "art is missing?"
label def Lismiss 0 0_valid 1 1_missing
label val art_ismiss Lismiss
tabulate art art_ismiss, missing

//  #5 listing only missing values

tab1 phd if missing(phd), miss
tab1 phd art cit if missing(phd), missing

foreach varname in phd art cit {
    tab1 `varname' if missing(`varname'), missing
}

//  missing data that probably isn't missing ================================

    use wf-misstype, clear

    * missing value codes
    label def Lmissdat      ///
        .c "c_catskip"      /// categorical answer not needed
        .d "d_nodebrief"    /// declined to be debriefed
        .f "f_femskip"      /// not asked since R is female
        .m "m_maleskip"     /// not asked since R is male
        .p "p_priorref"     /// not asked since R refused prelim question
        .r "r_refused"      /// refused to answer question
        .s "s_single"       /// not asked since single
        .x "x_nosxrel"      /// not asked since no sexual relationships
        .z "z_prior_0"      /// not asked since reported 0 on lead-in question

    * years married: V2 indicates reason for missing
    clonevar maryearV2 = maryear
    replace maryearV2 = .r if maryear==.a  // refused question
    replace maryearV2 = .s if married==2   // single
    replace maryearV2 = .p if married==.a  // married question refused
    label val maryearV2 Lmissdat
    tab1 maryearV2 if !missing(maryearV2)

    * months married
    clonevar marmthV2 = marmth
    recode marmthV2 .a=.r
    replace marmthV2 = .s if married==2  // single
    replace marmthV2 = .p if married==.a // married question refused
    label val marmthV2 Lmissdat
    tab1 marmthV2 if !missing(marmthV2)

    * years plus months married
    generate martotal = (maryearV2*12) + marmthV2
    label var martotal "Total months married"
    replace martotal = .s if married==2     // single
    replace martotal = .p if married==.a    // married question refused
    replace martotal = .r if marmthV2==.r | maryearV2==.r
    label val martotal Lmissdat
    tab1 martotal if missing(martotal), missing

    * check the refusals
    list martotal maryearV2 marmthV2 if martotal==.r, clean

    * years plus months married - not missing if one component missing
    generate martotalV2 = .
    label var martotalV2 "Total months married"
    note martotalV2: missing only if both month and year missing / `tag'

    * replace valid year and month if both are nonmissing
    replace martotalV2 = (12*maryearV2) + marmthV2 ///
        if !missing(maryearV2) & !missing(marmthV2)

    * replace with year if only years is valid
    replace martotalV2 = 12*maryearV2 ///
        if !missing(maryearV2) & marmthV2==.r

    * replace month if only month is valid
    replace martotalV2 = marmthV2 if maryearV2==.r & !missing(marmthV2)

    * missing for single or prior question refusal
    replace martotalV2 = .s if married==2     // single
    replace martotalV2 = .p if married==.a      // married question refused
    label val martotalV2 missdat

    * check results
    tab1 martotalV2 if missing(martotalV2), miss
    tab1 maryearV2  if missing(maryearV2), miss
    tab1 marmthV2   if missing(marmthV2), miss

    * list all cases - to be certain, you can check all cases
    * sort martotalV2
    * list martotalV2 maryearV2 marmthV2, clean

//  internal consistency =====================================================

use wf-acjob, clear

* art and cit
tab cit if art==0, missing

* compare job and phd
compare job phd

gen job_phd = job - phd
label var job_phd "job-phd: >0 if better job"
note job_phd: `tag'
sort job phd, stable
list job_phd art ment fem cit fel job phd if job_phd>.65, clean

log close
exit
