capture log close
log using wflec-dual-stat01-ologit, replace text
version 13.1
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  WF lectures: dual workflow - stat 01 ologit of momwarm

//  Assumes esttab package by B. Jann is installed -search esttab-

local pgm wflec-dual-stat01-ologit
local dte 2017-06-16
local who Scott Long
local tag `pgm'.do `who' `dte'

//  #1 setup

use wflec-dual-data02, clear
datasignature confirm

//  #2 specify models

local lhsvars BNwarm BNkidsuf BNfamsuf BNnotboth BNjobsat BNindep
local m1rhs i.female age i.married logfaminc
local m2rhs `m1rhs' i.highered i.fulltime
local m3rhs `m2rhs' i.momworks i.kidsnone
local regvars `m3rhs'
local descvars : subinstr local m3rhs "i." "", all

//  #3 select sample

qui reg age `regvars' // quick way to select listwise deletion sample
keep if e(sample)

//  #4 descriptives

tab momwarm, miss
codebook `descvars', compact

//  #5 linear regression on ordinal outcome

eststo regm1: regress momwarm `m1rhs'
eststo regm2: regress momwarm `m2rhs'
eststo regm3: regress momwarm `m3rhs'

esttab regm1 regm2 regm3, ///
title(Table _. OLS Regression of Support for Working Mothers) ///
    star(* 0.05 ** 0.01 *** 0.001) ///
    nonumbers mtitles("(1)" "(2)" "(3)") ///
    label b(%12.3f) t(%12.3f) ar2 bic(1)

//  #6 ologit with AMEs

eststo olgtm1: ologit momwarm `m1rhs'
eststo olgtm2: ologit momwarm `m2rhs'
eststo olgtm3: ologit momwarm `m3rhs'

esttab olgtm1 olgtm2 olgtm3, ///
title(Table _. Ordinal logit of support for working mothers) ///
    star(* 0.05 ** 0.01 *** 0.001) ///
    nonumbers mtitles("(1)" "(2)" "(3)") ///
    label b(%12.3f) t(%12.3f) ar2 bic(1)

mchange, amount(1 sd)

log close
exit

    order(female age married religion logfaminc highered fulltime momworks kidsnone kidsthree) ///

addnote("Note: Excluded category is R has 1 or 2 children") ///
* religion kidsthree
